@@ -114,11 +114,10 @@ class BaseBot:
         :param channel: the channel that the user left
         """
 
-    async def on_channel_subscription(self, channel: Channel, msg: Message):
+    async def on_channel_subscription(self, subscriber: str, channel: Channel, msg: Message):
         """
         triggered when a user subscribes
         """
-        print(f'subscribed {msg}')
 
     # endregion
 
@@ -225,9 +224,9 @@ class BaseBot:
     def run(self):
         """runs/starts the bot, this is a blocking function that starts the mainloop"""
         self._running = True
-        get_event_loop().run_until_complete(self._mainloop())
+        get_event_loop().run_until_complete(self.mainloop())
 
-    async def _mainloop(self):
+    async def mainloop(self):
         """starts the bot, connects to twitch, then starts the message event loop"""
 
         await update_global_emotes()
@@ -295,9 +294,10 @@ class BaseBot:
 
 
             elif msg.type is MessageType.SUBSCRIPTION:
-                coro = self.on_channel_subscription(msg.channel, msg)
-                mod_coro = trigger_mod_event(Event.on_channel_subscription, msg.channel, msg, channel=msg.channel_name)
-                event_coro = trigger_event(Event.on_channel_subscription, msg.channel, msg)
+                coro = self.on_channel_subscription(msg.author, msg.channel, msg)
+                mod_coro = trigger_mod_event(Event.on_channel_subscription, msg.author, msg.channel, msg,
+                                             channel=msg.channel_name)
+                event_coro = trigger_event(Event.on_channel_subscription, msg.author, msg.channel, msg)
 
             elif msg.type is MessageType.PING:
                 self.irc.send_pong()
